@@ -4,14 +4,10 @@
 
 # ----------------------------------------------------------------------------
 
-__version__ = '2.9.10'
+__version__ = '2.9.15'
 
 # ----------------------------------------------------------------------------
 
-# Pro Exchange
-
-from ccxt.pro.base.exchange import Exchange  # noqa: F401
-
 # CCXT Pro exchanges (now this is mainly used for importing exchanges in WS tests)
 
 from ccxt.pro.alpaca import alpaca                                        # noqa: F401
